import {Component, OnInit, ViewChild} from '@angular/core';
import {AlarmService} from '../alarm.service';
import {pageSize} from '../../app.constants';
import {AlarmGroupComponent} from '../modal/alarm-group/alarm-group.component';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';

@Component({
    selector: 'smart-alarm-set',
    templateUrl: './alarm-set.component.html',
    styles: []
})
export class AlarmSetComponent implements OnInit {
    @ViewChild('smartAlarmGroup') smartAlarmGroup: AlarmGroupComponent;
    setList = [];
    alertGroupId;
    groupList = [];

    pageNum;
    pageCount = pageSize;
    totalNum;

    constructor(private alarmSer: AlarmService,private modalSer:NzModalService,
                private message:NzMessageService) {
    }

    ngOnInit() {
        this.getList();
        this.getGroupAlarm();
    }

    //获取推送设置列表
    getList() {
        const data = {
            eventPage: this.pageNum,
            pageRecords: this.pageCount,
            alertGroupId: this.alertGroupId
        };
        this.alarmSer.actionFind(data).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.setList = res.data.data;
                    this.totalNum = res.data.totalNum;
                }
            }
        );
    }

    //获取告警组
    getGroupAlarm() {
        this.alarmSer.alertGroupFind().subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.groupList = res.data;
                }
            }
        );
    }

    //添加告警组
    showGroupModal() {
        this.smartAlarmGroup.addModal();
    }

    //删除告警组
    deleteGroup(){
        this.modalSer.confirm({
            nzTitle: '删除',
            nzContent: '<b style="color: red;">确认删除该告警组吗？</b>',
            nzOkText: '确定',
            nzOkType: 'danger',
            nzOnOk: () => {
                const arr = {
                    ids:[]
                };
                arr.ids.push(this.alertGroupId);
                this.alarmSer.alertGroupDelete(arr).subscribe(
                    (res) => {
                        if (res.errCode == 10000) {
                            this.message.info('删除成功');
                        } else {
                            this.message.info(res.errMsg);
                        }
                    }
                );
            },
            nzCancelText: '取消',
            nzOnCancel: () => console.log('Cancel'),
        })
    }

    //修改告警组
    editGroup(){
        if(!this.alertGroupId){
            this.message.info('请选择需要编辑的分组');
            return false;
        }
        let arr = [];
        this.groupList.forEach(res=>{
            if(res.id == this.alertGroupId){
                arr = res;
            }
        });
        console.log(arr);
        this.smartAlarmGroup.editModal(arr);
    }

    change(e){}
}
